READMODE_R

Type Alias READMODE_R 

pub type READMODE_R = R<u8, READMODE_A>;
Reader of field READMODE

Aliased Type

pub struct READMODE_R { /* private fields */ }

Implementations

Source

impl READMODE_R

pub fn variant(&self) -> Variant<u8, READMODE_A>

Get enumerated values variant

pub fn is_no_miss_penalty(&self) -> bool

Checks if the value of the field is NO_MISS_PENALTY

pub fn is_low_power(&self) -> bool

Checks if the value of the field is LOW_POWER

pub fn is_deterministic(&self) -> bool

Checks if the value of the field is DETERMINISTIC