STEP_R

Type Alias STEP_R 

pub type STEP_R = R<u8, STEP_A>;
Reader of field STEP

Aliased Type

pub struct STEP_R { /* private fields */ }

Implementations

Source

impl STEP_R

pub fn variant(&self) -> Variant<u8, STEP_A>

Get enumerated values variant

pub fn is_step1(&self) -> bool

Checks if the value of the field is STEP1

pub fn is_step2(&self) -> bool

Checks if the value of the field is STEP2

pub fn is_step4(&self) -> bool

Checks if the value of the field is STEP4

pub fn is_step8(&self) -> bool

Checks if the value of the field is STEP8