Type Alias STEP_R
Source pub type STEP_R = R<u8, STEP_A>;
pub struct STEP_R { }
Get enumerated values variant
Checks if the value of the field is STEP1
Checks if the value of the field is STEP2
Checks if the value of the field is STEP4
Checks if the value of the field is STEP8